/*
 * $Id: KeyCache.java 292 2006-02-28 23:30:47Z davidb $
 *
 * Copyright (c) 2005 VeriSign, Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

package se.rfc.unbound.validator;

import java.util.Properties;

import org.xbill.DNS.Name;

import se.rfc.unbound.SRRset;

/**
 * This cache stores DNSSEC keying information. It is used by the validator.
 * 
 * @author davidb
 * @version $Rev: 292 $
 */
public interface KeyCache
{

  /**
   * Initialize the key cache.
   * 
   * @param config The configuration data.
   */
  public void init(Properties config);

  /**
   * Find a given DNSKEY rrset by its name. This will return the 'closest'
   * matching DNSKEY rrset, or a negative cache entry for the closest matching
   * name, or null if nothing relevant is in the cache.
   * 
   * @param n The name to search for.
   * @param dclass The class to search in.
   * 
   * @return an KeyEntry object containing either a DNSKEY SRRset, or a
   *         nullKeyName, or null, if there is nothing relevant in the cache.
   */
  public KeyEntry find(Name n, int dclass);
  
  /**
   * Given a DNSKEY SRRset, store the rrset. SRRsets that don't have the
   * SECURE security status will be discarded.
   * 
   * @param key_rrset The rrset to store.
   */
  public void store(SRRset key_rrset);

  /**
   * Given a Name, store a 'NULLKEY' entry at that name, for the given TTL.
   * Note that the TTL should be taken from the NSEC record that proves the
   * absence of the DS record.
   * 
   * @param n The name of the delegation point without a DS RRset.
   * @param dclass The class of the negative cache entry.
   * @param ttl The ttl of this cache entry.
   */
  public void store(Name n, int dclass, long ttl);
}
